@@ -28,8 +28,8 @@ __author__ = 'Orsiris de Jong'
 __copyright__ = 'Copyright (C) 2018-2020 Orsiris de Jong'
 __description__ = 'antivirus state and installed products retrieval'
 __licence__ = 'BSD 3 Clause'
-__version__ = '0.6.1'
-__build__ = '2021033001'
+__version__ = '0.7.1'
+__build__ = '2021070101'
 
 import re
 from typing import List, Union
@@ -135,7 +135,7 @@ def _securitycenter_get_product_update_state(state: hex) -> bool:
     }.get(state, 'undefined')
 
 
-def get_installed_antivirus_software() -> List[str]:
+def get_installed_antivirus_software() -> List[dict]:
     """
     Not happy with it either. But yet here we are... Thanks Microsoft for not having SecurityCenter2 on WinServers
     So we need to detect used AV engines by checking what is installed and do "best guesses"
@@ -146,11 +146,24 @@ def get_installed_antivirus_software() -> List[str]:
     potential_seccenter_av_engines = []
     potential_av_engines = []
 
-    result = windows_tools.wmi_queries.query_wmi('SELECT * FROM AntivirusProduct', namespace='SecurityCenter')
+    result = windows_tools.wmi_queries.query_wmi('SELECT * FROM AntivirusProduct', namespace='SecurityCenter',
+                                                 name='windows_tools.antivirus.get_installed_antivirus_software')
     try:
         for product in result:
-            potential_seccenter_av_engines.append({'name': product['displayName']})
-    # TypeError may happend when securityCenter namespace does not exist
+            av_engine = {}
+            try:
+                av_engine['name'] = product['displayName']
+            except KeyError:
+                pass
+            try:
+                state = product['productState']
+                av_engine['enabled'] = securitycenter_get_product_exec_state(state)
+                av_engine['is_up_to_date'] = securitycenter_get_product_update_state(state)
+                av_engine['type'] = securitycenter_get_product_type(state)
+            except KeyError:
+                pass
+            potential_seccenter_av_engines.append(av_engine)
+    # TypeError may happen when securityCenter namespace does not exist
     except (KeyError, TypeError):
         pass
 
@@ -175,3 +188,5 @@ def get_installed_antivirus_software() -> List[str]:
 
     av_engines = av_engines + potential_av_engines
     return av_engines
+
+
